#!/usr/bin/perl
use strict;
use warnings;
use Bio::SeqIO;

my $infile = $ARGV[0]; # fasta in
my $outfile = $ARGV[1]; # fasta out
my $n = $ARGV[2]; #min seqs per file

##  1 - if seqcount < n, skip this file
my $count=0;
my $infileIO = Bio::SeqIO->new(-file => "$infile", -format => 'fasta');
while ( my $seqIO = $infileIO->next_seq()) {
	$count++;
}
if ($count < $n ) {exit;}

my %seen_id;
my %seen_seq;

##  2 - print the reference sequence first
$infile =~ /.*\/([^_]+_[^_]+).*$/;
my $refseq = $1;
open (OFIL, '>', $outfile) or die "Couldn't open file $outfile: $!\n";

$infileIO = Bio::SeqIO->new(-file => "$infile", -format => 'fasta');
while ( my $seqIO = $infileIO->next_seq()) {
	#get seq information
	my $name = $seqIO->display_id();
	my $seq = $seqIO->seq();
	if ($name =~ /\Q$refseq\E/ ) {
    		$seen_id{$name} = 1;
		$seen_seq{$seq} = 1;
		#remove any illegal characters: :,() U
		$name =~ s/[:,()]/_/g;
		$seq =~ s/[U*]/X/gi;
		print OFIL ">$name\n$seq\n";
	}else{ next;}
}

##  3 - print the remaining sequences
$infileIO = Bio::SeqIO->new(-file => "$infile", -format => 'fasta');
while ( my $seqIO = $infileIO->next_seq()) {
	my $name = $seqIO->display_id();
	my $seq = $seqIO->seq();
	if ($seen_id{$name}) {
 		next;
	}elsif($seen_seq{$seq}){ 	
		next;
	}else{
    		$seen_id{$name} = 1;
		$seen_seq{$seq} = 1;
		#remove any illegal characters: :,() U
		$name =~ s/[:,()]/_/g;
		$seq =~ s/[U*]/X/gi;
		print OFIL ">$name\n$seq\n";
    }
}

close OFIL;

