#!/usr/bin/perl
use strict;
use warnings;
use Bio::SearchIO;
use Bio::SeqIO;

my $blastfile = $ARGV[0]; # raw blastoutput file
my $outdir = $ARGV[1]; # path to output fasta files
my $min_id = $ARGV[2]; #minimum sequence conservation cutoff (65)
my $max_species = $ARGV[3]; # maximum sequences to print per species (1)
my $min_len = $ARGV[4]; # minimum coverage for both hit and query for hit to be extracted
my $fasdir = $ARGV[5]; # path to dbs fasta files

$blastfile =~ /blastout\.(\d+).(\w)/;
my $count = $1;
my $type = $2;
	
my %fas_hash;
if ($type eq 'p') {
	my $fasfile = "$fasdir/db.$count.fa";
	my $fileIO = Bio::SeqIO->new(-file => "$fasfile", -format => 'fasta');
	
	while ( my $fasObj = $fileIO->next_seq()) {
		my $name = $fasObj->display_id();
		my $seq = $fasObj->seq();
	
		# hash stores the seqname (key) sequence (value)
		$fas_hash{$name} = $seq;
	}
}
	

# OPEN BLAST FILE
my $srchIO = Bio::SearchIO->new(-file => "$blastfile", -format => 'blast');
	
while ( my $resultObj = $srchIO->next_result() ) {
	# create species hash
	my %species_hash;
		
	# GET HIT INFORMATION
	my $numhitObj = $resultObj->num_hits();
	my $query = $resultObj->query_name();

  	# SKIP IF NO HITS
	if ($numhitObj == 0) {
		next;
	}
		
	my $outfile = "$outdir/$query/$query.$count.$type";
	open (OFIL, '>>', $outfile) or die "Couldn't open file $outfile: $!\n";
      			
    while ( my $hitObj = $resultObj->next_hit() ) {
		my $hspObj = $hitObj->next_hsp();
		my $conserv = $hspObj->frac_conserved();
        	
       	if ($conserv < $min_id) {
       		next;
       	}
	       
	    my $hit_name = $hitObj->name();
		$hit_name =~ /([^_]+_[^_]+)_.*/;
		my $hit_species = $1;
	    $species_hash{$hit_species}++;
				
		# MAX SEQ COUNT NOT MET
		if ( $species_hash{$hit_species} > $max_species ) {
			next;
		}
			
		my $querylen = $resultObj->query_length();
		my $hitlen = $hitObj->length();
		my $hspHlen = $hspObj->length('hit');
		my $hspQlen = $hspObj->length('query');
	    
		my $queryCov = $hspQlen / $querylen;
		my $hitCov = $hspHlen / $hitlen;
					
		if ($queryCov < $min_len || $hitCov < $min_len ) {
			next;
		}
						
		if ($type eq 'p') {

			print OFIL ">$hit_name" . "_" . "$conserv\n". "$fas_hash{$hit_name}\n";
					
		} else {
			
			my $seq = $hspObj->hit_string();
			$seq =~ s/-//g;
			my $new_name = $hit_name . 'est';
		
			print OFIL ">$new_name" . "_" . "$conserv\n". "$seq\n";													
		}	
	}
	close OFIL;

}

